package cn.com.qmth.stmms.biz.report.dao;

import cn.com.qmth.stmms.biz.report.model.ReportSubjectClass;

import org.springframework.data.jpa.repository.JpaSpecificationExecutor;
import org.springframework.data.jpa.repository.Modifying;
import org.springframework.data.jpa.repository.Query;
import org.springframework.data.repository.PagingAndSortingRepository;

import java.util.List;

/**
 * 课程班级成绩分析 Dao
 *
 * @author xuwenjin
 * @date 2019-04-16
 */
public interface ReportSubjectClassDao
        extends PagingAndSortingRepository<ReportSubjectClass, Integer>, JpaSpecificationExecutor<ReportSubjectClass> {

    @Modifying
    @Query("delete from ReportSubjectClass r where r.examId=?1 ")
    void deleteByExamId(Integer exmaId);


    /**
     * 获取课程班级分析数据
     *
     * @param examId
     * @param subjectCode
     * @return List<Object [ ]>
     */
    @Query(value = "SELECT " +
            "s.className," +
            "avg( s.objectiveScore + s.subjectiveScore ) ," +
            "max( s.objectiveScore + s.subjectiveScore ) ," +
            "min( s.objectiveScore + s.subjectiveScore ) ," +
            "sum( CASE WHEN ( s.objectiveScore + s.subjectiveScore ) >= e.passScore THEN 1 ELSE 0 END ) ," +
            "sum( CASE WHEN ( s.objectiveScore + s.subjectiveScore ) >= e.excellentScore THEN 1 ELSE 0 END ) ," +
            "count(s) " +
            "FROM " +
            "ExamStudent s ,Exam e " +
            "where s.examId = e.id " +
            "and " +
            "s.examId = ?1 AND s.subjectCode = ?2 and s.className is not null and s.absent = false " +
            "GROUP BY s.className")
    List<Object[]> queryReportSubjectClassData(Integer examId, String subjectCode);

}
